==> dylink-generator-2.1.0.21.RELEASE-sources.jar: cn/net/vidyo/framework/builder/meta/ColumnSchema.java <==
package cn.net.vidyo.framework.builder.meta;

import cn.net.vidyo.framework.builder.domain.DbColumnType;
import cn.net.vidyo.framework.builder.domain.IColumnType;
import cn.net.vidyo.framework.common.util.ValueUtil;
import java.util.HashMap;
import java.util.Map;


public class ColumnSchema {
    String name ="";
    String comment ="";
    String propertyName="";
    private String dataTypeName;
    private Integer Length=0;
    public String dbColumnTypeString;
    IColumnType columnType;
    boolean primaryKey;
    /**
     * 自定义查询字段列表
     */
    private Map<String, Object> customMap=new HashMap<>();


    public void convert(){
//        System.out.println(dataTypeName);
    }

    public String getFirstLetterName(){
        return ValueUtil.firstLetterName(name);
    }

    public String getGetMethodName(){
        if(columnType== DbColumnType.BOOLEAN){
            return "is"+getFirstLetterName();
        }
        return "get"+getFirstLetterName();
    }

    public String getCompareDefaultString(){
        if(columnType== DbColumnType.INTEGER ||
                columnType== DbColumnType.LONG ||
                columnType== DbColumnType.SHORT ||
                columnType== DbColumnType.DOUBLE ||
                columnType== DbColumnType.FLOAT ||
                columnType== DbColumnType.BASE_SHORT ||
                columnType== DbColumnType.BASE_DOUBLE ||
                columnType== DbColumnType.BASE_FLOAT ||
                columnType== DbColumnType.BASE_INT ||
                columnType== DbColumnType.BASE_LONG
        ){
            return ">0";
        }
        if(columnType== DbColumnType.STRING){
            return ".length()>0";
        }
        if(columnType== DbColumnType.BOOLEAN){
            return "!=null";
        }
        return "!="+columnType.getDefaultValue();
    }
    public String getSetMethodName(){
        return "set"+getFirstLetterName();
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
        this.propertyName=getFirstLetterName();
    }

    public String getCommentString() {
        if(comment!=null && comment.length()>0)
            return comment;
        return name;
    }
    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public String getDataTypeName() {
        return dataTypeName;
    }

    public void setDataTypeName(String dataTypeName) {
        this.dataTypeName = dataTypeName;
    }

    public Integer getLength() {
        return Length;
    }

    public void setLength(Integer length) {
        Length = length;
    }

    public String getDbColumnTypeString() {
        return dbColumnTypeString;
    }

    public void setDbColumnTypeString(String dbColumnTypeString) {
        this.dbColumnTypeString = dbColumnTypeString;
    }

    public IColumnType getColumnType() {
        return columnType;
    }

    public void setColumnType(IColumnType columnType) {
        this.columnType = columnType;
    }

    public boolean isPrimaryKey() {
        return primaryKey;
    }

    public void setPrimaryKey(boolean primaryKey) {
        this.primaryKey = primaryKey;
    }

    public Map<String, Object> getCustomMap() {
        return customMap;
    }

    public void setCustomMap(Map<String, Object> customMap) {
        this.customMap = customMap;
    }

}

==> dylink-generator-2.1.0.29.RELEASE-sources.jar: cn/net/vidyo/framework/builder/meta/ColumnSchema.java <==
package cn.net.vidyo.framework.builder.meta;

import cn.net.vidyo.framework.builder.domain.DbColumnType;
import cn.net.vidyo.framework.builder.domain.IColumnType;
import cn.net.vidyo.framework.common.util.ValueUtil;
import java.util.HashMap;
import java.util.Map;


public class ColumnSchema {
    String name ="";
    String comment ="";
    String propertyName="";
    private String dataTypeName;
    private Integer Length=0;
    public String dbColumnTypeString;
    IColumnType columnType;
    boolean primaryKey;
    /**
     * 自定义查询字段列表
     */
    private Map<String, Object> customMap=new HashMap<>();


    public void convert(){
//        System.out.println(dataTypeName);
    }

    public String firstCapitalLetterName(){
        return ValueUtil.firstCapitalLetterName(name);
    }
    public String getFirstLowercaseLetterName(){
        return ValueUtil.firstLowercaseLetterName(name);
    }


    public String getGetMethodName(){
        if(columnType== DbColumnType.BOOLEAN){
            return "is"+ firstCapitalLetterName();
        }
        return "get"+ firstCapitalLetterName();
    }

    public String getCompareDefaultString(){
        if(columnType==null){
            System.out.println("");
        }
        if(columnType== DbColumnType.INTEGER ||
                columnType== DbColumnType.LONG ||
                columnType== DbColumnType.SHORT ||
                columnType== DbColumnType.DOUBLE ||
                columnType== DbColumnType.FLOAT ||
                columnType== DbColumnType.BASE_SHORT ||
                columnType== DbColumnType.BASE_DOUBLE ||
                columnType== DbColumnType.BASE_FLOAT ||
                columnType== DbColumnType.BASE_INT ||
                columnType== DbColumnType.BASE_LONG
        ){
            return ">0";
        }
        if(columnType== DbColumnType.STRING){
            return ".length()>0";
        }
        if(columnType== DbColumnType.BOOLEAN){
            return "!=null";
        }
        return "!="+columnType.getDefaultValue();
    }
    public String getSetMethodName(){
        return "set"+ firstCapitalLetterName();
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = ValueUtil.firstLowercaseLetterName(name);
        this.propertyName= getFirstLowercaseLetterName();
    }

    public String getCommentString() {
        if(comment!=null && comment.length()>0)
            return comment;
        return name;
    }
    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public String getPropertyName() {
        return propertyName;
    }

    public void setPropertyName(String propertyName) {
        this.propertyName = propertyName;
    }

    public String getDataTypeName() {
        return dataTypeName;
    }

    public void setDataTypeName(String dataTypeName) {
        this.dataTypeName = dataTypeName;
    }

    public Integer getLength() {
        return Length;
    }

    public void setLength(Integer length) {
        Length = length;
    }

    public String getDbColumnTypeString() {
        return dbColumnTypeString;
    }

    public void setDbColumnTypeString(String dbColumnTypeString) {
        this.dbColumnTypeString = dbColumnTypeString;
    }

    public IColumnType getColumnType() {
        return columnType;
    }

    public void setColumnType(IColumnType columnType) {
        this.columnType = columnType;
    }

    public boolean isPrimaryKey() {
        return primaryKey;
    }

    public void setPrimaryKey(boolean primaryKey) {
        this.primaryKey = primaryKey;
    }

    public Map<String, Object> getCustomMap() {
        return customMap;
    }

    public void setCustomMap(Map<String, Object> customMap) {
        this.customMap = customMap;
    }

}
